ArtifactFieldInfo class

Inheritance

Constructors

ArtifactFieldInfo($AFld field)
const

Properties

field → $AFld
final
fieldType → Type
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
ownerType → Type
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeDescriptor → $AT
no setter

Methods

bind(Object instance) → ArtifactFieldMirror
getAnnotations<T>([Type? type]) → Iterable<T>
override
getValue(Object instance) → Object?
hasAnnotation<T>([Type? type]) → bool
override
mapFieldType<R>(R mapper<T>()) → R
mapFieldValue<R>(Object? value, R mapper<T>(T value)) → R
mapOwnerType<R>(R mapper<T>()) → R
mapOwnerValue<R>(Object? value, R mapper<T>(T value)) → R
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(Object instance, Object? value) → Object
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited