ArtifactFieldMirror class

Inheritance

Constructors

ArtifactFieldMirror($AFld field, Object instance)
const

Properties

field → $AFld
final
fieldType → Type
no setter
hashCode → int
The hash code for this object.
no setterinherited
info → ArtifactFieldInfo
no setter
instance → Object
final
iType → Type
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeDescriptor → $AT
no setter
value → Object?
no setter

Methods

getAnnotations<T>([Type? type]) → Iterable<T>
override
hasAnnotation<T>([Type? type]) → bool
override
mapFieldType<R>(R mapper<T>()) → R
mapFieldValue<R>(R mapper<T>(T value)) → R
mapOwnerType<R>(R mapper<T>()) → R
mapOwnerValue<R>(R mapper<T>(T value)) → R
modify(Object? newValue) → ArtifactFieldMirror
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withInstance(Object newInstance) → ArtifactFieldMirror

Operators

operator ==(Object other) → bool
The equality operator.
inherited