ArtifactMirror class

Inheritance

Constructors

ArtifactMirror($AClass _clazz, Object instance)
const

Properties

fields → Iterable<ArtifactFieldMirror>
no setter
hashCode → int
The hash code for this object.
no setterinherited
instance → Object
final
methods → Iterable<ArtifactMethodMirror>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ArtifactTypeMirror
no setter

Methods

callMethod(String name, {List orderedParameters = const <dynamic>[], Map<String, dynamic> namedParameters = const <String, dynamic>{}}) → Object?
field(String name) → ArtifactFieldMirror?
getAnnotatedFields<T>([Type? t]) → Iterable<ArtifactAnnotatedField<T>>
getAnnotatedMethods<T>([Type? t]) → Iterable<ArtifactAnnotatedMethod<T>>
getAnnotations<T>([Type? type]) → Iterable<T>
override
getFieldValue(String name) → Object?
hasAnnotation<T>([Type? type]) → bool
override
mapClassType<R>(R mapper<T>()) → R
mapClassValue<R>(R mapper<T>(T value)) → R
method(String name) → ArtifactMethodMirror?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFieldValue(String name, Object? value) → ArtifactMirror
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited